@@ -293,6 +293,9 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
         /*find the emission lines in each image column*/
         sinfo_new_intarray_set_value(sum_pointer, 0, 0);
+        sinfo_msg("input params: guess_w=%g guess_d1=%g guess_d2=%g min_diff=%g half_width=%d sigma=%g",
+                  cfg->guessBeginWavelength,cfg->guessDispersion1,
+                  cfg->guessDispersion2,cfg->mindiff,cfg->halfWidth,cfg->sigma);
 
         ck0( (check = sinfo_new_find_lines(im,
                         wave,
@@ -607,6 +610,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
             ck0(sinfo_dumpTblToFitParams(par, cfg->paramsList),
                 "reading tbl %s ", cfg->paramsList);
+
         }
 
         /* #allocate memory for the slitlet position array */
@@ -619,6 +623,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
   sinfo_msg("cfg->estimateIndicator=%d\n",cfg->estimateIndicator);
   sinfo_msg("cfg->fitEdgeIndicator=%d\n",cfg->fitEdgeIndicator);
          */
+        //sinfo_msg("ok0");
         if (cfg->fitBoltzIndicator == 1) {
             if (cfg->estimateIndicator == 1) {
                 /* #open the ASCII list of the slitlet positions--- */
@@ -649,6 +654,10 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
                 }
             } else {
                 sinfo_msg("sinfo_new_fit_slits_boltz");
+                /*
+                sinfo_msg("ok4 boxLength=%d ybox=%g diffTol=%g",
+                          cfg->boxLength, cfg->yBox,cfg->diffTol);
+		*/
                 fit = sinfo_new_fit_slits_boltz(im,
                                 par,
                                 sinfo_slit_pos,
@@ -656,6 +665,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
                                 cfg->yBox,
                                 cfg->diffTol );
 
+                //sinfo_msg("ok5");
                 if (fit < 0) {
                     sinfo_msg_error ( "sinfo_new_fit_slits_boltz failed" );
                     goto cleanup;
